# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchActionLearnedInfo(Base):
	"""The SwitchActionLearnedInfo class encapsulates a system managed switchActionLearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchActionLearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'switchActionLearnedInfo'

	def __init__(self, parent):
		super(SwitchActionLearnedInfo, self).__init__(parent)

	@property
	def ActionType(self):
		"""This describes the action associated with the flow entry

		Returns:
			str
		"""
		return self._get_attribute('actionType')

	@property
	def EthernetDestination(self):
		"""This describes Ethernet destination address.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestination')

	@property
	def EthernetSource(self):
		"""This describes Ethernet source address.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSource')

	@property
	def IpDscp(self):
		"""This describes the IP DSCP value for advertising.

		Returns:
			str
		"""
		return self._get_attribute('ipDscp')

	@property
	def Ipv4Destination(self):
		"""This describes the IPv4 destination address.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Destination')

	@property
	def Ipv4Source(self):
		"""This describes the IPv4 source address.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Source')

	@property
	def MaxByteLength(self):
		"""This describes the maximum amount of data from a packet that should be sent when the port is OFPP_CONTROLLER.

		Returns:
			number
		"""
		return self._get_attribute('maxByteLength')

	@property
	def OutputPort(self):
		"""This describes the output port through which the packet should be sent.

		Returns:
			number
		"""
		return self._get_attribute('outputPort')

	@property
	def QueueId(self):
		"""This describes the queue of the port in which the packet should be enqueued.

		Returns:
			number
		"""
		return self._get_attribute('queueId')

	@property
	def TransportDestination(self):
		"""This describes the transport destination address

		Returns:
			number
		"""
		return self._get_attribute('transportDestination')

	@property
	def TransportSource(self):
		"""This describes the transport source address

		Returns:
			number
		"""
		return self._get_attribute('transportSource')

	@property
	def VlanId(self):
		"""This describes the Value of the VLAN ID field.

		Returns:
			number
		"""
		return self._get_attribute('vlanId')

	@property
	def VlanPriority(self):
		"""This describes the VLAN priority

		Returns:
			number
		"""
		return self._get_attribute('vlanPriority')

	def find(self, ActionType=None, EthernetDestination=None, EthernetSource=None, IpDscp=None, Ipv4Destination=None, Ipv4Source=None, MaxByteLength=None, OutputPort=None, QueueId=None, TransportDestination=None, TransportSource=None, VlanId=None, VlanPriority=None):
		"""Finds and retrieves switchActionLearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve switchActionLearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all switchActionLearnedInfo data from the server.

		Args:
			ActionType (str): This describes the action associated with the flow entry
			EthernetDestination (str): This describes Ethernet destination address.
			EthernetSource (str): This describes Ethernet source address.
			IpDscp (str): This describes the IP DSCP value for advertising.
			Ipv4Destination (str): This describes the IPv4 destination address.
			Ipv4Source (str): This describes the IPv4 source address.
			MaxByteLength (number): This describes the maximum amount of data from a packet that should be sent when the port is OFPP_CONTROLLER.
			OutputPort (number): This describes the output port through which the packet should be sent.
			QueueId (number): This describes the queue of the port in which the packet should be enqueued.
			TransportDestination (number): This describes the transport destination address
			TransportSource (number): This describes the transport source address
			VlanId (number): This describes the Value of the VLAN ID field.
			VlanPriority (number): This describes the VLAN priority

		Returns:
			self: This instance with matching switchActionLearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switchActionLearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switchActionLearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Geneve(Base):
	"""The Geneve class encapsulates a user managed geneve node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Geneve property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'geneve'

	def __init__(self, parent):
		super(Geneve, self).__init__(parent)

	@property
	def CfmMp(self):
		"""An instance of the CfmMp class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.cfmmp.CfmMp)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.cfmmp import CfmMp
		return CfmMp(self)

	@property
	def Connector(self):
		"""An instance of the Connector class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return Connector(self)

	@property
	def Ethernet(self):
		"""An instance of the Ethernet class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ethernet.Ethernet)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ethernet import Ethernet
		return Ethernet(self)

	@property
	def Ipv4Loopback(self):
		"""An instance of the Ipv4Loopback class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv4loopback.Ipv4Loopback)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv4loopback import Ipv4Loopback
		return Ipv4Loopback(self)

	@property
	def Ipv6Loopback(self):
		"""An instance of the Ipv6Loopback class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv6loopback.Ipv6Loopback)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv6loopback import Ipv6Loopback
		return Ipv6Loopback(self)

	@property
	def LdpBasicRouter(self):
		"""An instance of the LdpBasicRouter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpbasicrouter.LdpBasicRouter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpbasicrouter import LdpBasicRouter
		return LdpBasicRouter(self)

	@property
	def LdpBasicRouterV6(self):
		"""An instance of the LdpBasicRouterV6 class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpbasicrouterv6.LdpBasicRouterV6)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpbasicrouterv6 import LdpBasicRouterV6
		return LdpBasicRouterV6(self)

	@property
	def LdpTargetedRouter(self):
		"""An instance of the LdpTargetedRouter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldptargetedrouter.LdpTargetedRouter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldptargetedrouter import LdpTargetedRouter
		return LdpTargetedRouter(self)

	@property
	def LdpTargetedRouterV6(self):
		"""An instance of the LdpTargetedRouterV6 class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldptargetedrouterv6.LdpTargetedRouterV6)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldptargetedrouterv6 import LdpTargetedRouterV6
		return LdpTargetedRouterV6(self)

	@property
	def TlvProfile(self):
		"""An instance of the TlvProfile class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile.TlvProfile)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile import TlvProfile
		return TlvProfile(self)

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableUdpCsum(self):
		"""DEPRECATED Enable UDP checksum for outgoing packets

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableUdpCsum')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def Ipv4Remote(self):
		"""DEPRECATED The IPv4 address of the remote tunnel endpoint

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4Remote')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def UdpDestPort(self):
		"""DEPRECATED The UDP port used for GENEVE communication

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('udpDestPort')

	@property
	def Vni(self):
		"""DEPRECATED The virtual network identifier for this tunnel endpoint

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vni')

	def update(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Updates a child instance of geneve on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Adds a new geneve node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved geneve data using find and the newly added geneve data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the geneve data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, Multiplier=None, Name=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves geneve data from the server.

		All named parameters support regex and can be used to selectively retrieve geneve data from the server.
		By default the find method takes no parameters and will retrieve all geneve data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching geneve data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of geneve data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the geneve data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, EnableUdpCsum=None, Ipv4Remote=None, UdpDestPort=None, Vni=None):
		"""Base class infrastructure that gets a list of geneve device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			EnableUdpCsum (str): optional regex of enableUdpCsum
			Ipv4Remote (str): optional regex of ipv4Remote
			UdpDestPort (str): optional regex of udpDestPort
			Vni (str): optional regex of vni

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



"""Demonstrates how to use the StatViewAssist class

This sample requires an already loaded configuration with at least 2 connected vports.

"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform
from ixnetwork_restpy.assistants.statistics.statviewassistant import StatViewAssistant
from ixnetwork_restpy.errors import *


# connect to a windows test platform using the default api server rest port
test_platform = TestPlatform('127.0.0.1', rest_port=11009, platform='windows')

# use the default session and get the root node of the hierarchy
ixnetwork = test_platform.Sessions.find().Ixnetwork

ixnetwork.info('negative test')
try:
    StatViewAssistant(ixnetwork, 'my test view', Timeout=5)
except NotFoundError as e:
    ixnetwork.info(e)

# get a list of all current statistic views that can be used in the StatViewAssistant
print(StatViewAssistant.GetViewNames(ixnetwork))

# create a stat view assistant for a statistics view
port_statistics = StatViewAssistant(ixnetwork, 'Port Statistics')

# print all the rows for a statistics view
print(port_statistics)

# add a filter so that only a single row is retrieved
port_statistics.AddRowFilter('Port Name', StatViewAssistant.REGEX, 'Port 1$')
print(port_statistics)

# demonstrate cell access
port_statistics.ClearRowFilters()
rows = port_statistics.Rows

# get the cell value at row 0, column 'Port Name'
print(rows[0]['Port Name'])

# get the cell value at row 1, column 'Stat Name'
print(rows[1]['Stat Name'])

# get the cell value at the first row that matches a regex of 'case insensitive endswith port 1', column 'Frames Tx.'
print(rows['(?i)port 1$']['Frames Tx.'])

ixnetwork.info('check that all ipv4 protocols are up')
protocols_summary = StatViewAssistant(ixnetwork, 'Protocols Summary')
protocols_summary.AddRowFilter('Protocol Type', StatViewAssistant.REGEX, '(?i)^ipv4?')
protocols_summary.CheckCondition('Sessions Not Started', StatViewAssistant.EQUAL, 0)
protocols_summary.CheckCondition('Sessions Down', StatViewAssistant.EQUAL, 0)

ixnetwork.info('traffic stat check')
traffic_statistics = StatViewAssistant(ixnetwork, 'Traffic Item Statistics')
tx_frames = traffic_statistics.Rows[0]['Tx Frames']
ixnetwork.info('tx frames: %s' % tx_frames)

transport.info('drilldown sample')
ixnetwork.info(traffic_statistics.DrillDownOptions())
ixnetwork.info(traffic_statistics.TargetRowFilters())
drilldown = traffic_statistics.Drilldown(0, traffic_statistics.DrillDownOptions()[0], traffic_statistics.TargetRowFilters()[0])
print(drilldown)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class L1Config(Base):
	"""The L1Config class encapsulates a required l1Config node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the L1Config property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'l1Config'

	def __init__(self, parent):
		super(L1Config, self).__init__(parent)

	@property
	def OAM(self):
		"""An instance of the OAM class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.oam.oam.OAM)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.oam.oam import OAM
		return OAM(self)._select()

	@property
	def AtlasFourHundredGigLan(self):
		"""An instance of the AtlasFourHundredGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.atlasfourhundredgiglan.atlasfourhundredgiglan.AtlasFourHundredGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.atlasfourhundredgiglan.atlasfourhundredgiglan import AtlasFourHundredGigLan
		return AtlasFourHundredGigLan(self)._select()

	@property
	def Atm(self):
		"""An instance of the Atm class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.atm.atm.Atm)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.atm.atm import Atm
		return Atm(self)._select()

	@property
	def Ethernet(self):
		"""An instance of the Ethernet class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.ethernet.Ethernet)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.ethernet import Ethernet
		return Ethernet(self)._select()

	@property
	def EthernetImpairment(self):
		"""An instance of the EthernetImpairment class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernetimpairment.ethernetimpairment.EthernetImpairment)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernetimpairment.ethernetimpairment import EthernetImpairment
		return EthernetImpairment(self)._select()

	@property
	def Ethernetvm(self):
		"""An instance of the Ethernetvm class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernetvm.ethernetvm.Ethernetvm)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernetvm.ethernetvm import Ethernetvm
		return Ethernetvm(self)._select()

	@property
	def Fc(self):
		"""An instance of the Fc class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.fc.fc.Fc)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.fc.fc import Fc
		return Fc(self)._select()

	@property
	def FortyGigLan(self):
		"""An instance of the FortyGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.fortygiglan.fortygiglan.FortyGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.fortygiglan.fortygiglan import FortyGigLan
		return FortyGigLan(self)._select()

	@property
	def HundredGigLan(self):
		"""An instance of the HundredGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.hundredgiglan.hundredgiglan.HundredGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.hundredgiglan.hundredgiglan import HundredGigLan
		return HundredGigLan(self)._select()

	@property
	def KrakenFourHundredGigLan(self):
		"""An instance of the KrakenFourHundredGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.krakenfourhundredgiglan.krakenfourhundredgiglan.KrakenFourHundredGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.krakenfourhundredgiglan.krakenfourhundredgiglan import KrakenFourHundredGigLan
		return KrakenFourHundredGigLan(self)._select()

	@property
	def NovusHundredGigLan(self):
		"""An instance of the NovusHundredGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novushundredgiglan.novushundredgiglan.NovusHundredGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novushundredgiglan.novushundredgiglan import NovusHundredGigLan
		return NovusHundredGigLan(self)._select()

	@property
	def NovusTenGigLan(self):
		"""An instance of the NovusTenGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novustengiglan.novustengiglan.NovusTenGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novustengiglan.novustengiglan import NovusTenGigLan
		return NovusTenGigLan(self)._select()

	@property
	def Pos(self):
		"""An instance of the Pos class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.pos.pos.Pos)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.pos.pos import Pos
		return Pos(self)._select()

	@property
	def RxFilters(self):
		"""An instance of the RxFilters class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.rxfilters.rxfilters.RxFilters)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.rxfilters.rxfilters import RxFilters
		return RxFilters(self)._select()

	@property
	def TenFortyHundredGigLan(self):
		"""An instance of the TenFortyHundredGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tenfortyhundredgiglan.tenfortyhundredgiglan.TenFortyHundredGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tenfortyhundredgiglan.tenfortyhundredgiglan import TenFortyHundredGigLan
		return TenFortyHundredGigLan(self)._select()

	@property
	def TenGigLan(self):
		"""An instance of the TenGigLan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengiglan.tengiglan.TenGigLan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengiglan.tengiglan import TenGigLan
		return TenGigLan(self)._select()

	@property
	def TenGigWan(self):
		"""An instance of the TenGigWan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengigwan.tengigwan.TenGigWan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengigwan.tengigwan import TenGigWan
		return TenGigWan(self)._select()

	@property
	def CurrentType(self):
		"""Indicates the five types of ports for configuration to choose from.

		Returns:
			str(atlasFourHundredGigLan|atlasFourHundredGigLanFcoe|atm|ethernet|ethernetFcoe|ethernetImpairment|ethernetvm|fc|fortyGigLan|fortyGigLanFcoe|hundredGigLan|hundredGigLanFcoe|krakenFourHundredGigLan|novusHundredGigLan|novusHundredGigLanFcoe|novusTenGigLan|novusTenGigLanFcoe|pos|tenFortyHundredGigLan|tenFortyHundredGigLanFcoe|tenGigLan|tenGigLanFcoe|tenGigWan|tenGigWanFcoe)
		"""
		return self._get_attribute('currentType')
	@CurrentType.setter
	def CurrentType(self, value):
		self._set_attribute('currentType', value)

	def update(self, CurrentType=None):
		"""Updates a child instance of l1Config on the server.

		Args:
			CurrentType (str(atlasFourHundredGigLan|atlasFourHundredGigLanFcoe|atm|ethernet|ethernetFcoe|ethernetImpairment|ethernetvm|fc|fortyGigLan|fortyGigLanFcoe|hundredGigLan|hundredGigLanFcoe|krakenFourHundredGigLan|novusHundredGigLan|novusHundredGigLanFcoe|novusTenGigLan|novusTenGigLanFcoe|pos|tenFortyHundredGigLan|tenFortyHundredGigLanFcoe|tenGigLan|tenGigLanFcoe|tenGigWan|tenGigWanFcoe)): Indicates the five types of ports for configuration to choose from.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TlvProfile(Base):
	"""The TlvProfile class encapsulates a system managed tlvProfile node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TlvProfile property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'tlvProfile'

	def __init__(self, parent):
		super(TlvProfile, self).__init__(parent)

	@property
	def DefaultTlv(self):
		"""An instance of the DefaultTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.defaulttlv.DefaultTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.defaulttlv import DefaultTlv
		return DefaultTlv(self)

	@property
	def Tlv(self):
		"""An instance of the Tlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlv.Tlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlv import Tlv
		return Tlv(self)

	def find(self):
		"""Finds and retrieves tlvProfile data from the server.

		All named parameters support regex and can be used to selectively retrieve tlvProfile data from the server.
		By default the find method takes no parameters and will retrieve all tlvProfile data from the server.

		Returns:
			self: This instance with matching tlvProfile data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of tlvProfile data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the tlvProfile data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def CopyTlv(self, *args, **kwargs):
		"""Executes the copyTlv operation on the server.

		Copy a template tlv to a topology tlv profile

		copyTlv(Arg2:href)href
			Args:
				args[0] is Arg2 (str(None|/api/v1/sessions/1/ixnetwork/globals?deepchild=topology)): An object reference to a source template tlv

			Returns:
				str(None): An object reference to the newly created topology tlv as a result of the copy operation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('copyTlv', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class NeighborRange(Base):
	"""The NeighborRange class encapsulates a user managed neighborRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the NeighborRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'neighborRange'

	def __init__(self, parent):
		super(NeighborRange, self).__init__(parent)

	@property
	def Bgp4VpnBgpAdVplsRange(self):
		"""An instance of the Bgp4VpnBgpAdVplsRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.bgp4vpnbgpadvplsrange.Bgp4VpnBgpAdVplsRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.bgp4vpnbgpadvplsrange import Bgp4VpnBgpAdVplsRange
		return Bgp4VpnBgpAdVplsRange(self)

	@property
	def EthernetSegments(self):
		"""An instance of the EthernetSegments class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.ethernetsegments.EthernetSegments)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.ethernetsegments import EthernetSegments
		return EthernetSegments(self)

	@property
	def InterfaceLearnedInfo(self):
		"""An instance of the InterfaceLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.interfacelearnedinfo.InterfaceLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.interfacelearnedinfo import InterfaceLearnedInfo
		return InterfaceLearnedInfo(self)._select()

	@property
	def L2Site(self):
		"""An instance of the L2Site class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.l2site.L2Site)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.l2site import L2Site
		return L2Site(self)

	@property
	def L3Site(self):
		"""An instance of the L3Site class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.l3site.L3Site)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.l3site import L3Site
		return L3Site(self)

	@property
	def LearnedFilter(self):
		"""An instance of the LearnedFilter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedfilter.LearnedFilter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedfilter import LearnedFilter
		return LearnedFilter(self)._select()

	@property
	def LearnedInformation(self):
		"""An instance of the LearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedinformation.LearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedinformation import LearnedInformation
		return LearnedInformation(self)._select()

	@property
	def MplsRouteRange(self):
		"""An instance of the MplsRouteRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.mplsrouterange.MplsRouteRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.mplsrouterange import MplsRouteRange
		return MplsRouteRange(self)

	@property
	def OpaqueRouteRange(self):
		"""An instance of the OpaqueRouteRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.opaquerouterange.OpaqueRouteRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.opaquerouterange import OpaqueRouteRange
		return OpaqueRouteRange(self)

	@property
	def RouteImportOptions(self):
		"""An instance of the RouteImportOptions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.routeimportoptions.RouteImportOptions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.routeimportoptions import RouteImportOptions
		return RouteImportOptions(self)

	@property
	def RouteRange(self):
		"""An instance of the RouteRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.routerange.RouteRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.routerange import RouteRange
		return RouteRange(self)

	@property
	def UserDefinedAfiSafi(self):
		"""An instance of the UserDefinedAfiSafi class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.userdefinedafisafi.UserDefinedAfiSafi)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.userdefinedafisafi import UserDefinedAfiSafi
		return UserDefinedAfiSafi(self)

	@property
	def AsNumMode(self):
		"""DEPRECATED (External only) Indicates that each new session uses a different AS number.

		Returns:
			str(fixed|increment)
		"""
		return self._get_attribute('asNumMode')
	@AsNumMode.setter
	def AsNumMode(self, value):
		self._set_attribute('asNumMode', value)

	@property
	def Authentication(self):
		"""DEPRECATED Select the type of cryptographic authentication to be used for the BGP peers in this peer range.

		Returns:
			str(null|md5)
		"""
		return self._get_attribute('authentication')
	@Authentication.setter
	def Authentication(self, value):
		self._set_attribute('authentication', value)

	@property
	def BfdModeOfOperation(self):
		"""DEPRECATED Indicates whether to use a single-hop or a multi-hop mode of operation for the BFD session being created with a BGP peer.

		Returns:
			str(multiHop|singleHop)
		"""
		return self._get_attribute('bfdModeOfOperation')
	@BfdModeOfOperation.setter
	def BfdModeOfOperation(self, value):
		self._set_attribute('bfdModeOfOperation', value)

	@property
	def BgpId(self):
		"""DEPRECATED The BGP ID used in OPEN messages.

		Returns:
			str
		"""
		return self._get_attribute('bgpId')
	@BgpId.setter
	def BgpId(self, value):
		self._set_attribute('bgpId', value)

	@property
	def DutIpAddress(self):
		"""DEPRECATED The IP address of the DUT router.

		Returns:
			str
		"""
		return self._get_attribute('dutIpAddress')
	@DutIpAddress.setter
	def DutIpAddress(self, value):
		self._set_attribute('dutIpAddress', value)

	@property
	def Enable4ByteAsNum(self):
		"""DEPRECATED Enables the 4-byte Autonomous System (AS) number of the DUT/SUT.

		Returns:
			bool
		"""
		return self._get_attribute('enable4ByteAsNum')
	@Enable4ByteAsNum.setter
	def Enable4ByteAsNum(self, value):
		self._set_attribute('enable4ByteAsNum', value)

	@property
	def EnableActAsRestarted(self):
		"""DEPRECATED Controls the operation of BGP Graceful Restart.

		Returns:
			bool
		"""
		return self._get_attribute('enableActAsRestarted')
	@EnableActAsRestarted.setter
	def EnableActAsRestarted(self, value):
		self._set_attribute('enableActAsRestarted', value)

	@property
	def EnableBfdRegistration(self):
		"""DEPRECATED Enables the BFD registration.

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdRegistration')
	@EnableBfdRegistration.setter
	def EnableBfdRegistration(self, value):
		self._set_attribute('enableBfdRegistration', value)

	@property
	def EnableBgpId(self):
		"""DEPRECATED The BGP ID used in OPEN messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableBgpId')
	@EnableBgpId.setter
	def EnableBgpId(self, value):
		self._set_attribute('enableBgpId', value)

	@property
	def EnableDiscardIxiaGeneratedRoutes(self):
		"""DEPRECATED If true, enables the discard of Ixia generated routes

		Returns:
			bool
		"""
		return self._get_attribute('enableDiscardIxiaGeneratedRoutes')
	@EnableDiscardIxiaGeneratedRoutes.setter
	def EnableDiscardIxiaGeneratedRoutes(self, value):
		self._set_attribute('enableDiscardIxiaGeneratedRoutes', value)

	@property
	def EnableGracefulRestart(self):
		"""DEPRECATED Controls the operation of BGP Graceful Restart.

		Returns:
			bool
		"""
		return self._get_attribute('enableGracefulRestart')
	@EnableGracefulRestart.setter
	def EnableGracefulRestart(self, value):
		self._set_attribute('enableGracefulRestart', value)

	@property
	def EnableLinkFlap(self):
		"""DEPRECATED If true, enables link flap

		Returns:
			bool
		"""
		return self._get_attribute('enableLinkFlap')
	@EnableLinkFlap.setter
	def EnableLinkFlap(self, value):
		self._set_attribute('enableLinkFlap', value)

	@property
	def EnableNextHop(self):
		"""DEPRECATED Used for IPv4 traffic. Controls the use of the NEXT_HOP attribute. (default = disabled)

		Returns:
			bool
		"""
		return self._get_attribute('enableNextHop')
	@EnableNextHop.setter
	def EnableNextHop(self, value):
		self._set_attribute('enableNextHop', value)

	@property
	def EnableOptionalParameters(self):
		"""DEPRECATED Controls how an OPEN is conducted in the presence of optional parameters.

		Returns:
			bool
		"""
		return self._get_attribute('enableOptionalParameters')
	@EnableOptionalParameters.setter
	def EnableOptionalParameters(self, value):
		self._set_attribute('enableOptionalParameters', value)

	@property
	def EnableSendIxiaSignatureWithRoutes(self):
		"""DEPRECATED If true, enables sending of Ixia signature with routes

		Returns:
			bool
		"""
		return self._get_attribute('enableSendIxiaSignatureWithRoutes')
	@EnableSendIxiaSignatureWithRoutes.setter
	def EnableSendIxiaSignatureWithRoutes(self, value):
		self._set_attribute('enableSendIxiaSignatureWithRoutes', value)

	@property
	def EnableStaggeredStart(self):
		"""DEPRECATED Controls the staggering and period of initial start messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableStaggeredStart')
	@EnableStaggeredStart.setter
	def EnableStaggeredStart(self, value):
		self._set_attribute('enableStaggeredStart', value)

	@property
	def Enabled(self):
		"""DEPRECATED Enables or disables simulation of the router.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Evpn(self):
		"""DEPRECATED If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.

		Returns:
			bool
		"""
		return self._get_attribute('evpn')
	@Evpn.setter
	def Evpn(self, value):
		self._set_attribute('evpn', value)

	@property
	def EvpnNextHopCount(self):
		"""DEPRECATED It is used to replicate the traffic among the available Next Hops in Ingress Replication mode. Default value is 1. Minimum value is 1 and maximum value is 255.

		Returns:
			number
		"""
		return self._get_attribute('evpnNextHopCount')
	@EvpnNextHopCount.setter
	def EvpnNextHopCount(self, value):
		self._set_attribute('evpnNextHopCount', value)

	@property
	def HoldTimer(self):
		"""DEPRECATED The period of time between KEEP-ALIVE messages sent to the DUT.

		Returns:
			number
		"""
		return self._get_attribute('holdTimer')
	@HoldTimer.setter
	def HoldTimer(self, value):
		self._set_attribute('holdTimer', value)

	@property
	def InterfaceStartIndex(self):
		"""DEPRECATED The assigned protocol interface ID for this SM interface.

		Returns:
			number
		"""
		return self._get_attribute('interfaceStartIndex')
	@InterfaceStartIndex.setter
	def InterfaceStartIndex(self, value):
		self._set_attribute('interfaceStartIndex', value)

	@property
	def InterfaceType(self):
		"""DEPRECATED The type of interface to be selected for this BGP interface. One of:Protocol Interface, DHCP, PPP

		Returns:
			str
		"""
		return self._get_attribute('interfaceType')
	@InterfaceType.setter
	def InterfaceType(self, value):
		self._set_attribute('interfaceType', value)

	@property
	def Interfaces(self):
		"""DEPRECATED The interfaces that are associated with the selected interface type.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range)
		"""
		return self._get_attribute('interfaces')
	@Interfaces.setter
	def Interfaces(self, value):
		self._set_attribute('interfaces', value)

	@property
	def IpV4Mdt(self):
		"""DEPRECATED Enables the use of this Data MDT range on the simulated interface.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Mdt')
	@IpV4Mdt.setter
	def IpV4Mdt(self, value):
		self._set_attribute('ipV4Mdt', value)

	@property
	def IpV4Mpls(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv4 MPLS address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Mpls')
	@IpV4Mpls.setter
	def IpV4Mpls(self, value):
		self._set_attribute('ipV4Mpls', value)

	@property
	def IpV4MplsVpn(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv4 MPLS/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4MplsVpn')
	@IpV4MplsVpn.setter
	def IpV4MplsVpn(self, value):
		self._set_attribute('ipV4MplsVpn', value)

	@property
	def IpV4Multicast(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv4 multicast address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Multicast')
	@IpV4Multicast.setter
	def IpV4Multicast(self, value):
		self._set_attribute('ipV4Multicast', value)

	@property
	def IpV4MulticastVpn(self):
		"""DEPRECATED If true, this BGP router/peer supports the IPv4 Multicast/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4MulticastVpn')
	@IpV4MulticastVpn.setter
	def IpV4MulticastVpn(self, value):
		self._set_attribute('ipV4MulticastVpn', value)

	@property
	def IpV4Unicast(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv4 unicast address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Unicast')
	@IpV4Unicast.setter
	def IpV4Unicast(self, value):
		self._set_attribute('ipV4Unicast', value)

	@property
	def IpV6Mpls(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv6 MPLS address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Mpls')
	@IpV6Mpls.setter
	def IpV6Mpls(self, value):
		self._set_attribute('ipV6Mpls', value)

	@property
	def IpV6MplsVpn(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv6 MPLS/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6MplsVpn')
	@IpV6MplsVpn.setter
	def IpV6MplsVpn(self, value):
		self._set_attribute('ipV6MplsVpn', value)

	@property
	def IpV6Multicast(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv6 multicast address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Multicast')
	@IpV6Multicast.setter
	def IpV6Multicast(self, value):
		self._set_attribute('ipV6Multicast', value)

	@property
	def IpV6MulticastVpn(self):
		"""DEPRECATED If true, this BGP router/peer supports the IPv6 Multicast/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6MulticastVpn')
	@IpV6MulticastVpn.setter
	def IpV6MulticastVpn(self, value):
		self._set_attribute('ipV6MulticastVpn', value)

	@property
	def IpV6Unicast(self):
		"""DEPRECATED If enabled, this BGP router/peer supports the IPv6 unicast address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Unicast')
	@IpV6Unicast.setter
	def IpV6Unicast(self, value):
		self._set_attribute('ipV6Unicast', value)

	@property
	def IsAsbr(self):
		"""DEPRECATED If true, it is ASBR

		Returns:
			bool
		"""
		return self._get_attribute('isAsbr')
	@IsAsbr.setter
	def IsAsbr(self, value):
		self._set_attribute('isAsbr', value)

	@property
	def IsInterfaceLearnedInfoAvailable(self):
		"""DEPRECATED If true, learned information is made avavilable.

		Returns:
			bool
		"""
		return self._get_attribute('isInterfaceLearnedInfoAvailable')

	@property
	def IsLearnedInfoRefreshed(self):
		"""DEPRECATED If true, learned information is refreshed.

		Returns:
			bool
		"""
		return self._get_attribute('isLearnedInfoRefreshed')

	@property
	def LinkFlapDownTime(self):
		"""DEPRECATED Signifies the link flap down time

		Returns:
			number
		"""
		return self._get_attribute('linkFlapDownTime')
	@LinkFlapDownTime.setter
	def LinkFlapDownTime(self, value):
		self._set_attribute('linkFlapDownTime', value)

	@property
	def LinkFlapUpTime(self):
		"""DEPRECATED Signifies the link flap up time

		Returns:
			number
		"""
		return self._get_attribute('linkFlapUpTime')
	@LinkFlapUpTime.setter
	def LinkFlapUpTime(self, value):
		self._set_attribute('linkFlapUpTime', value)

	@property
	def LocalAsNumber(self):
		"""DEPRECATED (External only) The first AS Num assigned to the simulated neighbor router. May be set for external neighbors on any port type, but only Linux-based ports may set this for internal neighbors.

		Returns:
			str
		"""
		return self._get_attribute('localAsNumber')
	@LocalAsNumber.setter
	def LocalAsNumber(self, value):
		self._set_attribute('localAsNumber', value)

	@property
	def LocalIpAddress(self):
		"""DEPRECATED The first IP address for the simulated neighbor routers and the number of routers.

		Returns:
			str
		"""
		return self._get_attribute('localIpAddress')
	@LocalIpAddress.setter
	def LocalIpAddress(self, value):
		self._set_attribute('localIpAddress', value)

	@property
	def Md5Key(self):
		"""DEPRECATED (Active only when MD5 is selected in the Authentication Type field.) (String) Enter a value to be used as a secret MD5 Key for authentication. The maximum length allowed is 255 characters.One MD5 key can be configured per BGP peer range. Sessions from all peers in this peer range will use this MD5 key if MD5 is enabled.

		Returns:
			str
		"""
		return self._get_attribute('md5Key')
	@Md5Key.setter
	def Md5Key(self, value):
		self._set_attribute('md5Key', value)

	@property
	def NextHop(self):
		"""DEPRECATED If enableNextHop is true, this is the IPv4 address used as the next hop. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('nextHop')
	@NextHop.setter
	def NextHop(self, value):
		self._set_attribute('nextHop', value)

	@property
	def NumUpdatesPerIteration(self):
		"""DEPRECATED When the protocol server operates on older ports that do not possess a local processor, this tuning parameter controls how many UPDATE messages will be sent at a time. When many routers are being simulated on such a port, changing this value may help to increase or decrease performance. (default = 1)

		Returns:
			number
		"""
		return self._get_attribute('numUpdatesPerIteration')
	@NumUpdatesPerIteration.setter
	def NumUpdatesPerIteration(self, value):
		self._set_attribute('numUpdatesPerIteration', value)

	@property
	def RangeCount(self):
		"""DEPRECATED The number of routers.

		Returns:
			number
		"""
		return self._get_attribute('rangeCount')
	@RangeCount.setter
	def RangeCount(self, value):
		self._set_attribute('rangeCount', value)

	@property
	def RemoteAsNumber(self):
		"""DEPRECATED The remote Autonomous System number associated with the routers.

		Returns:
			number
		"""
		return self._get_attribute('remoteAsNumber')
	@RemoteAsNumber.setter
	def RemoteAsNumber(self, value):
		self._set_attribute('remoteAsNumber', value)

	@property
	def RestartTime(self):
		"""DEPRECATED Controls the operation of BGP Graceful Restart.

		Returns:
			number
		"""
		return self._get_attribute('restartTime')
	@RestartTime.setter
	def RestartTime(self, value):
		self._set_attribute('restartTime', value)

	@property
	def StaggeredStartPeriod(self):
		"""DEPRECATED Controls the staggering and period of initial start messages.

		Returns:
			number
		"""
		return self._get_attribute('staggeredStartPeriod')
	@StaggeredStartPeriod.setter
	def StaggeredStartPeriod(self, value):
		self._set_attribute('staggeredStartPeriod', value)

	@property
	def StaleTime(self):
		"""DEPRECATED Controls the operation of BGP Graceful Restart.

		Returns:
			number
		"""
		return self._get_attribute('staleTime')
	@StaleTime.setter
	def StaleTime(self, value):
		self._set_attribute('staleTime', value)

	@property
	def TcpWindowSize(self):
		"""DEPRECATED (External neighbor only) The TCP window used for communications from the neighbor. (default = 8,192)

		Returns:
			number
		"""
		return self._get_attribute('tcpWindowSize')
	@TcpWindowSize.setter
	def TcpWindowSize(self, value):
		self._set_attribute('tcpWindowSize', value)

	@property
	def TrafficGroupId(self):
		"""DEPRECATED The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	@property
	def TtlValue(self):
		"""DEPRECATED The limited number of iterations that a unit of data can experience before the data is discarded.

		Returns:
			number
		"""
		return self._get_attribute('ttlValue')
	@TtlValue.setter
	def TtlValue(self, value):
		self._set_attribute('ttlValue', value)

	@property
	def Type(self):
		"""DEPRECATED Indicates that the neighbor is either an internal or external router.

		Returns:
			str(internal|external)
		"""
		return self._get_attribute('type')
	@Type.setter
	def Type(self, value):
		self._set_attribute('type', value)

	@property
	def UpdateInterval(self):
		"""DEPRECATED The frequency with which UPDATE messages are sent to the DUT.

		Returns:
			number
		"""
		return self._get_attribute('updateInterval')
	@UpdateInterval.setter
	def UpdateInterval(self, value):
		self._set_attribute('updateInterval', value)

	@property
	def Vpls(self):
		"""DEPRECATED If enabled, this BGP router/peer supports BGP VPLS per the Kompella draft.

		Returns:
			bool
		"""
		return self._get_attribute('vpls')
	@Vpls.setter
	def Vpls(self, value):
		self._set_attribute('vpls', value)

	def update(self, AsNumMode=None, Authentication=None, BfdModeOfOperation=None, BgpId=None, DutIpAddress=None, Enable4ByteAsNum=None, EnableActAsRestarted=None, EnableBfdRegistration=None, EnableBgpId=None, EnableDiscardIxiaGeneratedRoutes=None, EnableGracefulRestart=None, EnableLinkFlap=None, EnableNextHop=None, EnableOptionalParameters=None, EnableSendIxiaSignatureWithRoutes=None, EnableStaggeredStart=None, Enabled=None, Evpn=None, EvpnNextHopCount=None, HoldTimer=None, InterfaceStartIndex=None, InterfaceType=None, Interfaces=None, IpV4Mdt=None, IpV4Mpls=None, IpV4MplsVpn=None, IpV4Multicast=None, IpV4MulticastVpn=None, IpV4Unicast=None, IpV6Mpls=None, IpV6MplsVpn=None, IpV6Multicast=None, IpV6MulticastVpn=None, IpV6Unicast=None, IsAsbr=None, LinkFlapDownTime=None, LinkFlapUpTime=None, LocalAsNumber=None, LocalIpAddress=None, Md5Key=None, NextHop=None, NumUpdatesPerIteration=None, RangeCount=None, RemoteAsNumber=None, RestartTime=None, StaggeredStartPeriod=None, StaleTime=None, TcpWindowSize=None, TrafficGroupId=None, TtlValue=None, Type=None, UpdateInterval=None, Vpls=None):
		"""Updates a child instance of neighborRange on the server.

		Args:
			AsNumMode (str(fixed|increment)): (External only) Indicates that each new session uses a different AS number.
			Authentication (str(null|md5)): Select the type of cryptographic authentication to be used for the BGP peers in this peer range.
			BfdModeOfOperation (str(multiHop|singleHop)): Indicates whether to use a single-hop or a multi-hop mode of operation for the BFD session being created with a BGP peer.
			BgpId (str): The BGP ID used in OPEN messages.
			DutIpAddress (str): The IP address of the DUT router.
			Enable4ByteAsNum (bool): Enables the 4-byte Autonomous System (AS) number of the DUT/SUT.
			EnableActAsRestarted (bool): Controls the operation of BGP Graceful Restart.
			EnableBfdRegistration (bool): Enables the BFD registration.
			EnableBgpId (bool): The BGP ID used in OPEN messages.
			EnableDiscardIxiaGeneratedRoutes (bool): If true, enables the discard of Ixia generated routes
			EnableGracefulRestart (bool): Controls the operation of BGP Graceful Restart.
			EnableLinkFlap (bool): If true, enables link flap
			EnableNextHop (bool): Used for IPv4 traffic. Controls the use of the NEXT_HOP attribute. (default = disabled)
			EnableOptionalParameters (bool): Controls how an OPEN is conducted in the presence of optional parameters.
			EnableSendIxiaSignatureWithRoutes (bool): If true, enables sending of Ixia signature with routes
			EnableStaggeredStart (bool): Controls the staggering and period of initial start messages.
			Enabled (bool): Enables or disables simulation of the router.
			Evpn (bool): If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.
			EvpnNextHopCount (number): It is used to replicate the traffic among the available Next Hops in Ingress Replication mode. Default value is 1. Minimum value is 1 and maximum value is 255.
			HoldTimer (number): The period of time between KEEP-ALIVE messages sent to the DUT.
			InterfaceStartIndex (number): The assigned protocol interface ID for this SM interface.
			InterfaceType (str): The type of interface to be selected for this BGP interface. One of:Protocol Interface, DHCP, PPP
			Interfaces (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range)): The interfaces that are associated with the selected interface type.
			IpV4Mdt (bool): Enables the use of this Data MDT range on the simulated interface.
			IpV4Mpls (bool): If enabled, this BGP router/peer supports the IPv4 MPLS address family.
			IpV4MplsVpn (bool): If enabled, this BGP router/peer supports the IPv4 MPLS/VPN address family.
			IpV4Multicast (bool): If enabled, this BGP router/peer supports the IPv4 multicast address family.
			IpV4MulticastVpn (bool): If true, this BGP router/peer supports the IPv4 Multicast/VPN address family.
			IpV4Unicast (bool): If enabled, this BGP router/peer supports the IPv4 unicast address family.
			IpV6Mpls (bool): If enabled, this BGP router/peer supports the IPv6 MPLS address family.
			IpV6MplsVpn (bool): If enabled, this BGP router/peer supports the IPv6 MPLS/VPN address family.
			IpV6Multicast (bool): If enabled, this BGP router/peer supports the IPv6 multicast address family.
			IpV6MulticastVpn (bool): If true, this BGP router/peer supports the IPv6 Multicast/VPN address family.
			IpV6Unicast (bool): If enabled, this BGP router/peer supports the IPv6 unicast address family.
			IsAsbr (bool): If true, it is ASBR
			LinkFlapDownTime (number): Signifies the link flap down time
			LinkFlapUpTime (number): Signifies the link flap up time
			LocalAsNumber (str): (External only) The first AS Num assigned to the simulated neighbor router. May be set for external neighbors on any port type, but only Linux-based ports may set this for internal neighbors.
			LocalIpAddress (str): The first IP address for the simulated neighbor routers and the number of routers.
			Md5Key (str): (Active only when MD5 is selected in the Authentication Type field.) (String) Enter a value to be used as a secret MD5 Key for authentication. The maximum length allowed is 255 characters.One MD5 key can be configured per BGP peer range. Sessions from all peers in this peer range will use this MD5 key if MD5 is enabled.
			NextHop (str): If enableNextHop is true, this is the IPv4 address used as the next hop. (default = 0.0.0.0)
			NumUpdatesPerIteration (number): When the protocol server operates on older ports that do not possess a local processor, this tuning parameter controls how many UPDATE messages will be sent at a time. When many routers are being simulated on such a port, changing this value may help to increase or decrease performance. (default = 1)
			RangeCount (number): The number of routers.
			RemoteAsNumber (number): The remote Autonomous System number associated with the routers.
			RestartTime (number): Controls the operation of BGP Graceful Restart.
			StaggeredStartPeriod (number): Controls the staggering and period of initial start messages.
			StaleTime (number): Controls the operation of BGP Graceful Restart.
			TcpWindowSize (number): (External neighbor only) The TCP window used for communications from the neighbor. (default = 8,192)
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TtlValue (number): The limited number of iterations that a unit of data can experience before the data is discarded.
			Type (str(internal|external)): Indicates that the neighbor is either an internal or external router.
			UpdateInterval (number): The frequency with which UPDATE messages are sent to the DUT.
			Vpls (bool): If enabled, this BGP router/peer supports BGP VPLS per the Kompella draft.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AsNumMode=None, Authentication=None, BfdModeOfOperation=None, BgpId=None, DutIpAddress=None, Enable4ByteAsNum=None, EnableActAsRestarted=None, EnableBfdRegistration=None, EnableBgpId=None, EnableDiscardIxiaGeneratedRoutes=None, EnableGracefulRestart=None, EnableLinkFlap=None, EnableNextHop=None, EnableOptionalParameters=None, EnableSendIxiaSignatureWithRoutes=None, EnableStaggeredStart=None, Enabled=None, Evpn=None, EvpnNextHopCount=None, HoldTimer=None, InterfaceStartIndex=None, InterfaceType=None, Interfaces=None, IpV4Mdt=None, IpV4Mpls=None, IpV4MplsVpn=None, IpV4Multicast=None, IpV4MulticastVpn=None, IpV4Unicast=None, IpV6Mpls=None, IpV6MplsVpn=None, IpV6Multicast=None, IpV6MulticastVpn=None, IpV6Unicast=None, IsAsbr=None, LinkFlapDownTime=None, LinkFlapUpTime=None, LocalAsNumber=None, LocalIpAddress=None, Md5Key=None, NextHop=None, NumUpdatesPerIteration=None, RangeCount=None, RemoteAsNumber=None, RestartTime=None, StaggeredStartPeriod=None, StaleTime=None, TcpWindowSize=None, TrafficGroupId=None, TtlValue=None, Type=None, UpdateInterval=None, Vpls=None):
		"""Adds a new neighborRange node on the server and retrieves it in this instance.

		Args:
			AsNumMode (str(fixed|increment)): (External only) Indicates that each new session uses a different AS number.
			Authentication (str(null|md5)): Select the type of cryptographic authentication to be used for the BGP peers in this peer range.
			BfdModeOfOperation (str(multiHop|singleHop)): Indicates whether to use a single-hop or a multi-hop mode of operation for the BFD session being created with a BGP peer.
			BgpId (str): The BGP ID used in OPEN messages.
			DutIpAddress (str): The IP address of the DUT router.
			Enable4ByteAsNum (bool): Enables the 4-byte Autonomous System (AS) number of the DUT/SUT.
			EnableActAsRestarted (bool): Controls the operation of BGP Graceful Restart.
			EnableBfdRegistration (bool): Enables the BFD registration.
			EnableBgpId (bool): The BGP ID used in OPEN messages.
			EnableDiscardIxiaGeneratedRoutes (bool): If true, enables the discard of Ixia generated routes
			EnableGracefulRestart (bool): Controls the operation of BGP Graceful Restart.
			EnableLinkFlap (bool): If true, enables link flap
			EnableNextHop (bool): Used for IPv4 traffic. Controls the use of the NEXT_HOP attribute. (default = disabled)
			EnableOptionalParameters (bool): Controls how an OPEN is conducted in the presence of optional parameters.
			EnableSendIxiaSignatureWithRoutes (bool): If true, enables sending of Ixia signature with routes
			EnableStaggeredStart (bool): Controls the staggering and period of initial start messages.
			Enabled (bool): Enables or disables simulation of the router.
			Evpn (bool): If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.
			EvpnNextHopCount (number): It is used to replicate the traffic among the available Next Hops in Ingress Replication mode. Default value is 1. Minimum value is 1 and maximum value is 255.
			HoldTimer (number): The period of time between KEEP-ALIVE messages sent to the DUT.
			InterfaceStartIndex (number): The assigned protocol interface ID for this SM interface.
			InterfaceType (str): The type of interface to be selected for this BGP interface. One of:Protocol Interface, DHCP, PPP
			Interfaces (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range)): The interfaces that are associated with the selected interface type.
			IpV4Mdt (bool): Enables the use of this Data MDT range on the simulated interface.
			IpV4Mpls (bool): If enabled, this BGP router/peer supports the IPv4 MPLS address family.
			IpV4MplsVpn (bool): If enabled, this BGP router/peer supports the IPv4 MPLS/VPN address family.
			IpV4Multicast (bool): If enabled, this BGP router/peer supports the IPv4 multicast address family.
			IpV4MulticastVpn (bool): If true, this BGP router/peer supports the IPv4 Multicast/VPN address family.
			IpV4Unicast (bool): If enabled, this BGP router/peer supports the IPv4 unicast address family.
			IpV6Mpls (bool): If enabled, this BGP router/peer supports the IPv6 MPLS address family.
			IpV6MplsVpn (bool): If enabled, this BGP router/peer supports the IPv6 MPLS/VPN address family.
			IpV6Multicast (bool): If enabled, this BGP router/peer supports the IPv6 multicast address family.
			IpV6MulticastVpn (bool): If true, this BGP router/peer supports the IPv6 Multicast/VPN address family.
			IpV6Unicast (bool): If enabled, this BGP router/peer supports the IPv6 unicast address family.
			IsAsbr (bool): If true, it is ASBR
			LinkFlapDownTime (number): Signifies the link flap down time
			LinkFlapUpTime (number): Signifies the link flap up time
			LocalAsNumber (str): (External only) The first AS Num assigned to the simulated neighbor router. May be set for external neighbors on any port type, but only Linux-based ports may set this for internal neighbors.
			LocalIpAddress (str): The first IP address for the simulated neighbor routers and the number of routers.
			Md5Key (str): (Active only when MD5 is selected in the Authentication Type field.) (String) Enter a value to be used as a secret MD5 Key for authentication. The maximum length allowed is 255 characters.One MD5 key can be configured per BGP peer range. Sessions from all peers in this peer range will use this MD5 key if MD5 is enabled.
			NextHop (str): If enableNextHop is true, this is the IPv4 address used as the next hop. (default = 0.0.0.0)
			NumUpdatesPerIteration (number): When the protocol server operates on older ports that do not possess a local processor, this tuning parameter controls how many UPDATE messages will be sent at a time. When many routers are being simulated on such a port, changing this value may help to increase or decrease performance. (default = 1)
			RangeCount (number): The number of routers.
			RemoteAsNumber (number): The remote Autonomous System number associated with the routers.
			RestartTime (number): Controls the operation of BGP Graceful Restart.
			StaggeredStartPeriod (number): Controls the staggering and period of initial start messages.
			StaleTime (number): Controls the operation of BGP Graceful Restart.
			TcpWindowSize (number): (External neighbor only) The TCP window used for communications from the neighbor. (default = 8,192)
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TtlValue (number): The limited number of iterations that a unit of data can experience before the data is discarded.
			Type (str(internal|external)): Indicates that the neighbor is either an internal or external router.
			UpdateInterval (number): The frequency with which UPDATE messages are sent to the DUT.
			Vpls (bool): If enabled, this BGP router/peer supports BGP VPLS per the Kompella draft.

		Returns:
			self: This instance with all currently retrieved neighborRange data using find and the newly added neighborRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the neighborRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AsNumMode=None, Authentication=None, BfdModeOfOperation=None, BgpId=None, DutIpAddress=None, Enable4ByteAsNum=None, EnableActAsRestarted=None, EnableBfdRegistration=None, EnableBgpId=None, EnableDiscardIxiaGeneratedRoutes=None, EnableGracefulRestart=None, EnableLinkFlap=None, EnableNextHop=None, EnableOptionalParameters=None, EnableSendIxiaSignatureWithRoutes=None, EnableStaggeredStart=None, Enabled=None, Evpn=None, EvpnNextHopCount=None, HoldTimer=None, InterfaceStartIndex=None, InterfaceType=None, Interfaces=None, IpV4Mdt=None, IpV4Mpls=None, IpV4MplsVpn=None, IpV4Multicast=None, IpV4MulticastVpn=None, IpV4Unicast=None, IpV6Mpls=None, IpV6MplsVpn=None, IpV6Multicast=None, IpV6MulticastVpn=None, IpV6Unicast=None, IsAsbr=None, IsInterfaceLearnedInfoAvailable=None, IsLearnedInfoRefreshed=None, LinkFlapDownTime=None, LinkFlapUpTime=None, LocalAsNumber=None, LocalIpAddress=None, Md5Key=None, NextHop=None, NumUpdatesPerIteration=None, RangeCount=None, RemoteAsNumber=None, RestartTime=None, StaggeredStartPeriod=None, StaleTime=None, TcpWindowSize=None, TrafficGroupId=None, TtlValue=None, Type=None, UpdateInterval=None, Vpls=None):
		"""Finds and retrieves neighborRange data from the server.

		All named parameters support regex and can be used to selectively retrieve neighborRange data from the server.
		By default the find method takes no parameters and will retrieve all neighborRange data from the server.

		Args:
			AsNumMode (str(fixed|increment)): (External only) Indicates that each new session uses a different AS number.
			Authentication (str(null|md5)): Select the type of cryptographic authentication to be used for the BGP peers in this peer range.
			BfdModeOfOperation (str(multiHop|singleHop)): Indicates whether to use a single-hop or a multi-hop mode of operation for the BFD session being created with a BGP peer.
			BgpId (str): The BGP ID used in OPEN messages.
			DutIpAddress (str): The IP address of the DUT router.
			Enable4ByteAsNum (bool): Enables the 4-byte Autonomous System (AS) number of the DUT/SUT.
			EnableActAsRestarted (bool): Controls the operation of BGP Graceful Restart.
			EnableBfdRegistration (bool): Enables the BFD registration.
			EnableBgpId (bool): The BGP ID used in OPEN messages.
			EnableDiscardIxiaGeneratedRoutes (bool): If true, enables the discard of Ixia generated routes
			EnableGracefulRestart (bool): Controls the operation of BGP Graceful Restart.
			EnableLinkFlap (bool): If true, enables link flap
			EnableNextHop (bool): Used for IPv4 traffic. Controls the use of the NEXT_HOP attribute. (default = disabled)
			EnableOptionalParameters (bool): Controls how an OPEN is conducted in the presence of optional parameters.
			EnableSendIxiaSignatureWithRoutes (bool): If true, enables sending of Ixia signature with routes
			EnableStaggeredStart (bool): Controls the staggering and period of initial start messages.
			Enabled (bool): Enables or disables simulation of the router.
			Evpn (bool): If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.
			EvpnNextHopCount (number): It is used to replicate the traffic among the available Next Hops in Ingress Replication mode. Default value is 1. Minimum value is 1 and maximum value is 255.
			HoldTimer (number): The period of time between KEEP-ALIVE messages sent to the DUT.
			InterfaceStartIndex (number): The assigned protocol interface ID for this SM interface.
			InterfaceType (str): The type of interface to be selected for this BGP interface. One of:Protocol Interface, DHCP, PPP
			Interfaces (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range|/api/v1/sessions/1/ixnetwork/vport?deepchild=range)): The interfaces that are associated with the selected interface type.
			IpV4Mdt (bool): Enables the use of this Data MDT range on the simulated interface.
			IpV4Mpls (bool): If enabled, this BGP router/peer supports the IPv4 MPLS address family.
			IpV4MplsVpn (bool): If enabled, this BGP router/peer supports the IPv4 MPLS/VPN address family.
			IpV4Multicast (bool): If enabled, this BGP router/peer supports the IPv4 multicast address family.
			IpV4MulticastVpn (bool): If true, this BGP router/peer supports the IPv4 Multicast/VPN address family.
			IpV4Unicast (bool): If enabled, this BGP router/peer supports the IPv4 unicast address family.
			IpV6Mpls (bool): If enabled, this BGP router/peer supports the IPv6 MPLS address family.
			IpV6MplsVpn (bool): If enabled, this BGP router/peer supports the IPv6 MPLS/VPN address family.
			IpV6Multicast (bool): If enabled, this BGP router/peer supports the IPv6 multicast address family.
			IpV6MulticastVpn (bool): If true, this BGP router/peer supports the IPv6 Multicast/VPN address family.
			IpV6Unicast (bool): If enabled, this BGP router/peer supports the IPv6 unicast address family.
			IsAsbr (bool): If true, it is ASBR
			IsInterfaceLearnedInfoAvailable (bool): If true, learned information is made avavilable.
			IsLearnedInfoRefreshed (bool): If true, learned information is refreshed.
			LinkFlapDownTime (number): Signifies the link flap down time
			LinkFlapUpTime (number): Signifies the link flap up time
			LocalAsNumber (str): (External only) The first AS Num assigned to the simulated neighbor router. May be set for external neighbors on any port type, but only Linux-based ports may set this for internal neighbors.
			LocalIpAddress (str): The first IP address for the simulated neighbor routers and the number of routers.
			Md5Key (str): (Active only when MD5 is selected in the Authentication Type field.) (String) Enter a value to be used as a secret MD5 Key for authentication. The maximum length allowed is 255 characters.One MD5 key can be configured per BGP peer range. Sessions from all peers in this peer range will use this MD5 key if MD5 is enabled.
			NextHop (str): If enableNextHop is true, this is the IPv4 address used as the next hop. (default = 0.0.0.0)
			NumUpdatesPerIteration (number): When the protocol server operates on older ports that do not possess a local processor, this tuning parameter controls how many UPDATE messages will be sent at a time. When many routers are being simulated on such a port, changing this value may help to increase or decrease performance. (default = 1)
			RangeCount (number): The number of routers.
			RemoteAsNumber (number): The remote Autonomous System number associated with the routers.
			RestartTime (number): Controls the operation of BGP Graceful Restart.
			StaggeredStartPeriod (number): Controls the staggering and period of initial start messages.
			StaleTime (number): Controls the operation of BGP Graceful Restart.
			TcpWindowSize (number): (External neighbor only) The TCP window used for communications from the neighbor. (default = 8,192)
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TtlValue (number): The limited number of iterations that a unit of data can experience before the data is discarded.
			Type (str(internal|external)): Indicates that the neighbor is either an internal or external router.
			UpdateInterval (number): The frequency with which UPDATE messages are sent to the DUT.
			Vpls (bool): If enabled, this BGP router/peer supports BGP VPLS per the Kompella draft.

		Returns:
			self: This instance with matching neighborRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of neighborRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the neighborRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def GetInterfaceAccessorIfaceList(self):
		"""Executes the getInterfaceAccessorIfaceList operation on the server.

		?

			Returns:
				str: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('getInterfaceAccessorIfaceList', payload=payload, response_object=None)

	def GetInterfaceLearnedInfo(self):
		"""Executes the getInterfaceLearnedInfo operation on the server.

		This function allows to Get the interface learned information.

			Returns:
				str: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('getInterfaceLearnedInfo', payload=payload, response_object=None)

	def RefreshLearnedInfo(self):
		"""Executes the refreshLearnedInfo operation on the server.

		This function allows to refresh the BGP learned information from the DUT.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLearnedInfo', payload=payload, response_object=None)
